@@ -86,7 +86,7 @@ class CalendarPlugin(hildondesktop.HomeItem):
     self._prefSave('today',str(int(self._widgetTree.get_widget("btoday").get_active())))
     self._prefSave('tomorrow',str(int(self._widgetTree.get_widget("btomorrow").get_active())))
     self._prefSave('after_tomorrow',str(int(self._widgetTree.get_widget("bafter_tomorrow").get_active())))
-    self._prefSave('week',str(int(self._widgetTree.get_widget("week").get_active())))
+    self._prefSave('week',str(int(self._widgetTree.get_widget("bweek").get_active())))
     self._window.destroy()
 
   def _cancel(self,widget,*data):
@@ -267,7 +267,7 @@ class CalendarPlugin(hildondesktop.HomeItem):
     diff = datetime.timedelta(days=nb_day)
     last_day = date + diff
     return (first_day,last_day)
-    
+
   def get_week(self):
     week_start,week_end = self._get_week_details(datetime.datetime.now())
     event_uuid_list =  mcalendar_framework.EventList().get_events_for_date_interval(week_start,week_end)
@@ -279,7 +279,7 @@ class CalendarPlugin(hildondesktop.HomeItem):
       event = mcalendar_framework.Event(event_uuid)
       text = text + '\n '+event.start_datetime.strftime('%x-%X')+'-'+event.end_datetime.strftime('%X')+' : ' + event.title
     return text
-    
+
   def get_after_tomorrow(self):
     diff = datetime.timedelta(days=2)
     event_uuid_list =  mcalendar_framework.EventList().get_events_for_one_day(datetime.datetime.now()+diff)
@@ -293,16 +293,26 @@ class CalendarPlugin(hildondesktop.HomeItem):
     return text
 
   def get_text(self):
-    today = '<span foreground="'+self._prefRead('title')+'">Today</span>'+self.get_today()
-    tomorrow = '<span foreground="'+self._prefRead('title')+'">Tomorrow</span>'+self.get_tomorrow()
-    text = today + '\n\n'+tomorrow 
+    text = ''
+#    today = '<span foreground="'+self._prefRead('title')+'">Today</span>'+self.get_today()
+#    tomorrow = '<span foreground="'+self._prefRead('title')+'">Tomorrow</span>'+self.get_tomorrow()
+    if int(self._prefRead('today'))==1:
+      text = text + '<span foreground="'+self._prefRead('title')+'">Today</span>'+self.get_today()
+    if int(self._prefRead('tomorrow'))==1:
+      text = text +  '\n\n<span foreground="'+self._prefRead('title')+'">Tomorrow</span>'+self.get_tomorrow()
+    if int(self._prefRead('after_tomorrow'))==1:
+      text = text + '\n\n<span foreground="'+self._prefRead('title')+'">After tommorow</span>'+self.get_after_tomorrow()
+    if int(self._prefRead('week'))==1:
+      text = text + '\n\n<span foreground="'+self._prefRead('title')+'">Week</span>'+self.get_week()
+
+#    text = today + '\n\n'+tomorrow 
     return text
-    
+
 def hd_plugin_get_objects():
   plugin = CalendarPlugin()
   return [plugin]
 
 if __name__ == "__main__":
-  print CalendarPlugin()
+  print CalendarPlugin()._ShowSettings('')
   print CalendarPlugin().get_text()
   gtk.main()
